{% raw %}
{% load mote_tags %}
{% mask element.json.data.Menu as "menu" %}
<ul class="menu-list menu-list--standard">
  {% for item in menu.menu_list %}
    <li class="menu-list__item menu-list__item--standard">
      <a href="{{item.href}}" class="menu-list__anchor menu-list__anchor-standard">{{item.name}}</a>
    </li>
{% endfor %}
</ul>
{% endraw %}
