{% load wagtailcore_tags i18n %}
<div class="call-to-action">
  <a href="/" class="call-to-action__nav-item-text call-to-action__nav-item-text--{{direction}}">
    {% trans "Read All" %} {{ section }}
  </a>
</div>
